@@ -108,6 +108,7 @@ NO_BATTERY_SUPPORT_MODELS = {
     "SL-103",  # Linus L2
     "CERES",  # Smart code handle
     "Yale Linus L2",  # Linus L2 Nordic
+    "MD-04I",  # Yale Durus (EU)
 }
 
 AUTO_LOCK_DEFAULT_DURATION = 90
@@ -1197,5 +1198,5 @@ class PushLock:
 
 def get_homekit_state_num(data: bytes) -> int:
     """Get the homekit state number from the manufacturer data."""
-    acid, gsn, cn, cv = struct.unpack("<HHBB", data[9:15])
+    _acid, gsn, _cn, _cv = struct.unpack("<HHBB", data[9:15])
     return gsn
